@@ -1,11 +1,5 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::1_0::TestServer;
-$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::TestServer::VERSION = '7.301';
+package Search::Elasticsearch::Client::2_0::TestServer;
+$Search::Elasticsearch::Client::2_0::TestServer::VERSION = '5.02';
 use strict;
 use warnings;
 
@@ -44,19 +38,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::TestServer - Client-specific backend for Search::Elasticsearch::TestServer
+Search::Elasticsearch::Client::2_0::TestServer - Client-specific backend for Search::Elasticsearch::TestServer
 
 =head1 VERSION
 
-version 7.30_1
+version 5.02
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2017 by Elasticsearch BV.
 
 This is free software, licensed under:
 
